---
title: 파트너 정산 자동화 서비스 가이드
category: 관리자콘솔 (관리자콘솔 사용 가이드) > 파트너 정산 자동화 > 파트너 정산 자동화
seo:
  title: 파트너 정산 자동화 가이드
  description: >-
    재무, 개발 공수를 획기적으로 줄여주는 포트원의 파트너정산 자동화 서비스를 소개합니다. 간단한 API 연동과 관리자 콘솔을 통해 고객사
    자체 개발에 드는 많은 비용과 시간의 절감이 가능합니다.
  keywords:
    - 파트너정산
    - 파트너정산자동화
    - 관리자콘솔
tags:
  - 공통
  - 파트너 정산 자동화
pgCompanies:
  - 공통
searchTags:
  - 매출정산자동화
  - 지급이체
  - pg지급이체
  - 정산자동화
  - 하위정산
  - 파트너분담률
  - 할인정책
  - 할인분담금
  - 정산내역
  - 파트너추가
  - 파트너관리
  - 수식관리
  - 추가수수료정책
  - 수수료등록
  - 정산정책
  - 파트너계약
---

### **서비스 소개**

#### **1. 요약**

파트너 정산 자동화 서비스는 플랫폼, 마켓 플레이스, 커머스 사업을 위한 포트원만의 재무 서비스 모듈로 국내 최초로 개발되었습니다. 파트너에게 지급되어야 하는 정산 금액을 자동으로 계산하고 세금계산서, 송금(지급이체)까지 자동화함으로써 재무팀과, 운영팀, 개발팀 모두의 리소스를 획기적으로 절감할 수 있습니다. API 연동 및 포트원 관리자 콘솔을 통한 노코드 연동 모두 지원됩니다.

#### **2. 핵심 기능**

1. 개인 및 사업자 유형에 따라 다양한 정산 정책을 등록하고 관리할 수 있습니다.
2. 파트너를 대량으로 등록하고 손쉽게 관리할 수 있습니다.
3. 파트너별 정산 정책을 자동으로 매칭시켜서 정산 주기에 맞게 정산금을 자동으로 계산합니다.
4. 사업자 대상 세금계산서 역발행 요청 기능을 제공합니다. (런칭 예정)
5. 계산된 정산금을 클릭 한 번으로 송금 및 이체 처리할 수 있습니다.

#### **3. 용어 설명**

- 정산 서비스 이용에 참고하실 수 있는 [용어별 설명 가이드 보러가기↗](https://developers.portone.io/platform/guides/dictionary)를 안내드립니다.

### 상세 이용 가이드



#### 1. 정산정책관리

<Tag text="계약관리" />

**자동으로 정산데이터가 생성될 수 있도록 계약을 추가해주세요.**

- **중개수수료 설정**
  - 정률 (%) / 정액 (₩) 선택하여 설정가능
  - 부가세를 파트너에서 부담할지 설정가능
- **정산주기 설정**
  - 지체일 : 매출 1일, 정산 2일
    - 매출(결제)이 발생된 이후 홀드하고 있어야 하는 기간
  - 정산일 주기 설정
    - 매월 / 매주 / 매일 / 매년
    - N일 정산
  - **기준일 설정**
    - 전 영업일 / 후 영업일 / 달력일 중 선택가능
  - **아이디 생성 및 메모**
    - 아이디 생성 : 설정하신 계약에 대한 아이디를 부여합니다. 원하는 아이디로 설정하거나, 난수의 식별번호로 생성하실 수도 있습니다.
    - 메모 : 계약에 대한 메모 설정

<Tag text="할인 분담 정책" />

**API 호출할 때 진행하고 있는 프로모션 할인 비율을 적용하여 호출할 수 있습니다.**

- 할인 정책 아이디 : 설정할 할인정책을 구분할 아이디를 설정해주세요.
- 파트너 분담률 : 포인트 및 쿠폰으로 인한 할인금액에 대해서 파트너가 부담하기로 한 비율입니다.
- 메모 등록

<Tag text="추가 수수료 정책" />

**정산 건에 추가 수수료가 적용될 경우 등록하신 아이디를 전달해주셔야 합니다**

- 추가 수수료 아이디 : 추가하실 수수료 정책을 구분할 아이디를 설정해주세요.
- 추가 수수료 정보 : 정률(%) / 정액(₩)
- 부가세 분담 주체 : 파트너 부담 or 우리 회사 부담
- 메모 등록

<Tag text="수식관리" />

**아래 수식은 API 호출을 통해서 사용이 가능합니다.**

- 플랫폼 중개 수수료 수식
  - 사용가능 변수: 주문금액, 결제금액, 결제금액부가세, 결제금액부가세 부담금, 할인금액, 할인부담금, 정액(정액 플랫폼 중개 수수료), 정률(정률 플랫폼 중개 수수료)
- 할인 분담금 수식
  - 사용가능 변수: 할인금액, 정률(할인 분담률)
- 추가 수수료 수식
  - 사용가능 변수: 주문금액, 결제금액, 결제금액부가세, 결제금액부가세 부담금, 할인금액, 할인부담금, 플랫폼중개수수료, 플랫폼중개수수료부가세 부담금, 정액(정액 추가 수수료), 정률(정률 추가 수수료)
- 전체 수식 계산식
  - 정산 금액 = 주문 금액 - 결제금액부가세 부담금 -중개 수수료- 중개수수료부가세 부담금 -추가 수수료 - 추가수수료부가세 부담금 - 할인 부담금

#### 2. 파트너 관리

**정산이 이루어질 파트너를 등록합니다.**



<Tag text="파트너 추가" />

파트너 추가 기능은 포트원 관리자콘솔에서 수동처리 및 API 호출로 가능합니다.

- 정산 대상 설정
  - 사업자 정보 및 이름을 입력합니다.
- 계좌정보
  - 정산데이터가 생성될 정산받을 대상의 계좌정보를 설정합니다.
  - 이 때 1번에 등록한 계약 건과 연동합니다.
- 메모등록
  - 파트너에 대한 메모를 입력합니다.
- 태그등록
  - 우리 회사 내부적으로 쓰고 있는 규칙이 있다면 자유롭게 태그를 등록 그룹으로 만들어보세요. 이후에 필터 / 검색 시 활용할 수 있습니다.
- 아이디 생성
  - 정산 api에 사용될 아이디를 발급합니다. 원하는 아이디로 설정하거나, 난수의 식별번호로 생성하실 수 있습니다.
- 사용자 정의 속성 관리

#### 3. 정산 상세  조회

- 정산 API를 호출하여 정산일에 맞게 생성된 주문 정산, 주문 취소 정산 내역을 조회할 수 있습니다.
- 수기로 정산 내역 조정이 필요한 경우 음수 정산 / 양수 정산 건을 생성하여 예외적인 정산 케이스를 관리할 수 있습니다.



#### 4. **정산 내역 관리하기**

- 정산 내역 관리는 1시간마다 배치를 통해 동기화됩니다. 등록한 정산 상세 내역 중 \[정산일]이 도래한 정산 건은 자동 취합되며, 정산 내역 관리 페이지에서 조회할 수 있습니다.
- 이미 생성된 정산 내역이 있더라도 API 혹은 콘솔의 수기 정산 기능으로 해당 정산일에 추가 정산 내역을 등록하면, 정산 금액은 합산됩니다.
- 다만 기존의 정산 건이 지급실패/지급보류 상태로 변경된 경우, 추가 정산 내역을 등록하더라도 정산 금액은 합산되지 않고 새로운 정산 건이 별도로 생성됩니다.
- 송금대행 일괄지급은 기존에 즉시 지급만 가능하였으나, 이번 업데이트로 즉시 지급과 예약지급을 선택 하여 지급을 실행할 수 있습니다. 내부 정책에 맞게 지급 일시를 유연하게 관리해보세요. 



#### 5. **송금대행 일괄지급**

- \[정산내역 관리] 페이지에서 총 10개의 정산일자를 선택하여 원하는 정산내역을 선택하여 \[송금대행 일괄지급] 을 실행할 수 있습니다.
- 송금대행 일괄지급 서비스를 신청하는 경우, 전용 가상계좌가 부여됩니다.
- 예약지급과 즉시지급이 가능하며 즉시지급 선택 시 실시간으로 지급이 실행됩니다.



#### 6. **일괄지급 내역 관리**

- \[일괄지급 내역 관리]에서 일괄 지급 현황을 실시간으로 확인할 수 있습니다. 지급 오류를 방지하기 위해 지급은 시스템에서 차례로 진행되며, 2개 이상의 일괄지급을 동시에 진행할 수 없습니다.
- 정보 오기입 등의 사유로 송금대행 일괄 지급 중단이 필요하신 경우 \[중단] 버튼을 이용하여 즉시 지급을 중단할 수 있습니다. 지급중단 처리는 준비완료, 진행 중 상태일 때 가능합니다.



#### 7. **지급내역 관리**

- 지급 내역 관리 페이지에서 진행 중인 지급 현황을 확인할 수 있습니다.
- 지급이 실패한 경우, 실패 사유를 확인할 수 있습니다. 지급 실패 건에 대해 지급을 재시도하고자 하는 경우, \[정산 내역 관리] 페이지의 ‘지급실패’ 상태 탭에서 해당 지급 건을 확인한 뒤 새롭게 일괄지급을 실행할 수 있습니다.

